<?php

namespace Drupal\entity_usage\EventSubscriber;

use Drupal\entity_track\Events\EntityTrackBatchStartEvent;
use Drupal\entity_track\Events\Events;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class EntityTrackPurgeSubscriber.
 */
class EntityTrackPurgeSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    if (!class_exists('\Drupal\entity_track\Events\Events')) {
      return [];
    }
    $events[Events::BATCH_START] = ['purgeEntityUsage'];
    return $events;
  }

  /**
   * Deletes the entity usage statistics when a new tracking batch is started.
   *
   * @param \Drupal\entity_track\Events\EntityTrackBatchStartEvent $event
   *   The entity track batch start event.
   */
  public function purgeEntityUsage(EntityTrackBatchStartEvent $event): void {
    // Delete current usage statistics for all entities of this entity type.
    \Drupal::service('entity_usage.usage')->bulkDeleteSources($event->getSourceEntityType());
  }

}
