<?php

namespace Drupal\Tests\entity_usage\Kernel;

use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\file\Entity\File;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\file\Functional\FileFieldCreationTrait;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Tests files and images tracking.
 *
 * @group entity_usage
 */
class EntityUsageTrackFileTest extends KernelTestBase {

  use FileFieldCreationTrait;
  use TestFileCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_test',
    'entity_usage',
    'entity_track',
    'field',
    'file',
    'image',
    'system',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->createFileField(
      'file',
      'entity_test',
      'entity_test',
      [],
      ['file_extensions' => 'txt'],
    );
    FieldStorageConfig::create([
      'type' => 'image',
      'entity_type' => 'entity_test',
      'field_name' => 'image',
    ])->save();
    FieldConfig::create([
      'entity_type' => 'entity_test',
      'bundle' => 'entity_test',
      'field_name' => 'image',
      'label' => 'Image',
    ])->save();
    $this->installEntitySchema('entity_test');
    $this->installEntitySchema('file');
    $this->installSchema('entity_usage', ['entity_usage']);
    $this->installSchema('file', ['file_usage']);

    $this->config('entity_track.settings')
      ->set('track_enabled_entity_types', ['entity_test'])
      ->set('track_enabled_plugins', ['entity_reference'])
      ->save();

    $this->config('entity_usage.settings')
      ->set('track_enabled_target_entity_types', ['file', 'image'])
      ->save();
  }

  /**
   * Tests tracking files and images.
   */
  public function testFile(): void {
    $images = $this->getTestFiles('image');
    $entity = EntityTest::create([
      'type' => 'entity_test',
      'name' => $this->randomString(),
      'file' => File::create([
        'uri' => $this->generateFile($this->randomMachineName(), 1, 1, 'text'),
      ]),
      'image' => File::create([
        'uri' => $images[0]->uri,
      ]),
    ]);
    $entity->save();

    $this->assertSame([
      'file' => [
        $entity->get('image')->target_id => [
          [
            'method' => 'entity_reference',
            'field_name' => 'image',
            'count' => '1',
          ],
        ],
        $entity->get('file')->target_id => [
          [
            'method' => 'entity_reference',
            'field_name' => 'file',
            'count' => '1',
          ],
        ],
      ],
    ], $this->container->get('entity_usage.usage')->listTargets($entity));
  }

}
